# Changelog

## 0.1.0-alpha.1 (2024-11-16)

Full Changelog: [v0.0.1-alpha.1...v0.1.0-alpha.1](https://github.com/TralahM/paymaxis-python/compare/v0.0.1-alpha.1...v0.1.0-alpha.1)

### Features

* **api:** update via SDK Studio ([#3](https://github.com/TralahM/paymaxis-python/issues/3)) ([8dc6c1e](https://github.com/TralahM/paymaxis-python/commit/8dc6c1e7c36d9773087be366b730ad455ce2f193))
* **api:** update via SDK Studio ([#5](https://github.com/TralahM/paymaxis-python/issues/5)) ([0add1d2](https://github.com/TralahM/paymaxis-python/commit/0add1d2dd0a3dea97f064fb3b51f7ebce427ecb7))

## 0.0.1-alpha.1 (2024-11-16)

Full Changelog: [v0.0.1-alpha.0...v0.0.1-alpha.1](https://github.com/TralahM/paymaxis-python/compare/v0.0.1-alpha.0...v0.0.1-alpha.1)

### Chores

* go live ([bbff90c](https://github.com/TralahM/paymaxis-python/commit/bbff90c7bf8f383e7d20f7aae1eb8f5eece65e18))
* update SDK settings ([#2](https://github.com/TralahM/paymaxis-python/issues/2)) ([9372c1a](https://github.com/TralahM/paymaxis-python/commit/9372c1abbbbdbc2a3a230d20e5db31ee24a2fa6f))
